@@ -1,4 +1,4 @@
-# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2018-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,6 +10,7 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+"""Placeholder docstring"""
 from __future__ import absolute_import
 
 
@@ -25,4 +26,5 @@ def training_env():  # type: () -> _env.TrainingEnv
     return _env.TrainingEnv(
         resource_config=_env.read_resource_config(),
         input_data_config=_env.read_input_data_config(),
-        hyperparameters=_env.read_hyperparameters())
+        hyperparameters=_env.read_hyperparameters(),
+    )
